@@ -26,7 +26,7 @@ import (
 	"github.com/Azure/azure-sdk-for-go/services/resources/mgmt/2018-05-01/resources"
 	"github.com/Azure/go-autorest/autorest"
 	"github.com/Azure/go-autorest/autorest/to"
-	clusterv1 "github.com/openshift/cluster-api/pkg/apis/cluster/v1alpha1"
+	machinev1 "github.com/openshift/cluster-api/pkg/apis/machine/v1beta1"
 	clusterproviderv1 "sigs.k8s.io/cluster-api-provider-azure/pkg/apis/azureprovider/v1alpha1"
 	machineproviderv1 "sigs.k8s.io/cluster-api-provider-azure/pkg/apis/azureprovider/v1beta1"
 )
@@ -307,7 +307,7 @@ func MockRgDeleteFutureFailure() MockAzureResourcesClient {
 // MockDeploymentCreateOrUpdateSuccess mocks the DeploymentCreateOrUpdate success response.
 func MockDeploymentCreateOrUpdateSuccess() MockAzureResourcesClient {
 	return MockAzureResourcesClient{
-		MockCreateOrUpdateDeployment: func(machine *clusterv1.Machine, clusterConfig *clusterproviderv1.AzureClusterProviderSpec, machineConfig *machineproviderv1.AzureMachineProviderSpec) (*resources.DeploymentsCreateOrUpdateFuture, error) {
+		MockCreateOrUpdateDeployment: func(machine *machinev1.Machine, clusterConfig *clusterproviderv1.AzureClusterProviderSpec, machineConfig *machineproviderv1.AzureMachineProviderSpec) (*resources.DeploymentsCreateOrUpdateFuture, error) {
 			return &resources.DeploymentsCreateOrUpdateFuture{}, nil
 		},
 	}
@@ -316,7 +316,7 @@ func MockDeploymentCreateOrUpdateSuccess() MockAzureResourcesClient {
 // MockDeploymentCreateOrUpdateFailure mocks the DeploymentCreateOrUpdate failure response.
 func MockDeploymentCreateOrUpdateFailure() MockAzureResourcesClient {
 	return MockAzureResourcesClient{
-		MockCreateOrUpdateDeployment: func(machine *clusterv1.Machine, clusterConfig *clusterproviderv1.AzureClusterProviderSpec, machineConfig *machineproviderv1.AzureMachineProviderSpec) (*resources.DeploymentsCreateOrUpdateFuture, error) {
+		MockCreateOrUpdateDeployment: func(machine *machinev1.Machine, clusterConfig *clusterproviderv1.AzureClusterProviderSpec, machineConfig *machineproviderv1.AzureMachineProviderSpec) (*resources.DeploymentsCreateOrUpdateFuture, error) {
 			return nil, errors.New("failed to create resource")
 		},
 	}
@@ -352,7 +352,7 @@ func MockDeloymentGetResultFailure() MockAzureResourcesClient {
 // MockDeploymentValidate mocks the DeploymentValidate error response.
 func MockDeploymentValidate() MockAzureResourcesClient {
 	return MockAzureResourcesClient{
-		MockValidateDeployment: func(machine *clusterv1.Machine, clusterConfig *clusterproviderv1.AzureClusterProviderSpec, machineConfig *machineproviderv1.AzureMachineProviderSpec) error {
+		MockValidateDeployment: func(machine *machinev1.Machine, clusterConfig *clusterproviderv1.AzureClusterProviderSpec, machineConfig *machineproviderv1.AzureMachineProviderSpec) error {
 			return errors.New("error validating deployment")
 		},
 	}
